@@ -22,6 +22,7 @@
 # endif
 #endif
 
+#include "VERSION.h"
 #include "feature.h"
 
 #include <ctype.h>
@@ -75,8 +76,9 @@ static Display*	Xdisplay;	/* X display */
 static int	Xfd;		/* file descriptor of server connection */
 static GC	Xgc, Xrvgc;	/* normal, reverse video GC */
 
-#define	Xscreen		DefaultScreen(Xdisplay)
-#define Xcmap		DefaultColormap(Xdisplay,Xscreen)
+#define	Xscreen		DefaultScreen (Xdisplay)
+#define Xcmap		DefaultColormap (Xdisplay, Xscreen)
+#define Xroot		DefaultRootWindow (Xdisplay)
 
 /* windows and their sizes */
 typedef struct {
@@ -94,23 +96,19 @@ static const char *	rs_geometry = NULL;
 
 #ifdef ICONWIN
 static const char *	rs_iconGeometry = NULL;
-static mywindow_t	Icon = {None, 65, 65};	/* icon window */
-static int		iconic_state = NormalState; /* iconic startup? */
-#endif
-
-#if defined (REMINDERS) && !defined (CONFIG_FILE)
-# undef REMINDERS
+static mywindow_t	Icon = {None, 65, 65};		/* icon window */
+static int		iconic_state = NormalState;	/* iconic startup? */
 #endif
 
 #ifdef REMINDERS
-static mywindow_t	Msg = {0, 0, 0};    /* message window */
+static mywindow_t	Msg = {0, 0, 0};		/* message window */
 static struct {
    Window
-#ifndef NO_REMINDER_EXEC
+# ifndef NO_REMINDER_EXEC
      Start,
-#endif
-     Dismiss,
-     Defer;
+# endif
+   Dismiss,
+   Defer;
    int width, height;
 } msgButton;
 
@@ -118,13 +116,26 @@ static XFontStruct * Xfont;
 #define FontHeight()	(Xfont->ascent + Xfont->descent)
 static int	Msg_Mapped = 0;		/* message window mapped? */
 static int	reminderTime = -1;
+#ifdef ADJUST_TIME
+static int	adjustTime = 0;
+#else
+# define	adjustTime	0
+#endif
 static char	message [256] = "";
 #ifndef NO_REMINDER_EXEC
-static char	exec_prgm [256] = "";
+static char	execPrgm [256] = "";
 #endif
 static const char * reminders_file = NULL;	/* name of ~/.rclock file */
 #endif
 
+#ifdef	CENTURY
+# if (CENTURY < 1900)
+Error, Cenury incorrectly set.
+# endif
+#else
+# define CENTURY 1900
+#endif
+
 static int	clockUpdate = CLOCKUPDATE;
 
 #ifdef MAIL
@@ -145,14 +156,17 @@ static XSizeHints szHint = {
 };
 
 /* subroutine declarations */
-static void	geometry2sizehint (mywindow_t *win, const char * geom);
-static void	Create_Windows (int argc, char *argv[]);
+static void	geometry2sizehint (mywindow_t * /* win */,
+				   const char * /* geom */);
+static void	Create_Windows (int /* argc */,
+				char * /* argv */ []);
 static void	getXevent (void);
-static void	print_error (const char *fmt, ...);
+static void	print_error (const char * /* fmt */, ...);
 
-static void	Draw_Window (mywindow_t *this_win, int full_redraw);
+static void	Draw_Window (mywindow_t * /* this_win */,
+			     int /* full_redraw */);
 static void	Reminder (void);
-static void	Next_Reminder (int update_only);
+static void	Next_Reminder (int /* update_only */);
 
 /* Arguments for Next_Reminder() */
 #define REPLACE 0
@@ -178,6 +192,9 @@ usage (void)
 #endif
 #ifdef ICONWIN
 	{ "-iconic",		"start iconic" },
+#endif
+#ifdef ADJUST_TIME
+	{ "-adjust +/-ddhhmm",	"adjust clock time" },
 #endif
 	{ "-update seconds",	"clock update interval" },
 #ifdef MAIL
@@ -186,7 +203,7 @@ usage (void)
 	{ "#geom",		"icon window geometry" }
    };
 
-   fprintf (stderr, "\nUsage:\n  " APL_NAME " [options]\n\n"
+   fprintf (stderr, "\nUsage v" VERSION ":\n  " APL_NAME " [options]\n\n"
 	    "where options include:\n");
 
    for (i = 0; i < optList_size(); i++)
@@ -198,20 +215,20 @@ usage (void)
  * simple X windows clock with appointment reminder
  *----------------------------------------------------------------------*/
 int
-main (int argc, char *argv[])
+main (int argc, char * argv [])
 {
    int i;
-   char *opt, *val;
-   const char *display_name = NULL;
+   char * opt, * val;
+   const char * display_name = NULL;
    XGCValues gcv;
 
 #ifdef REMINDERS
-   const char *rs_font = FONT_NAME;
+   const char * rs_font = FONT_NAME;
 
    /* find the ~/.rclock file */
    if ((val = getenv ("HOME")) != NULL)
      {
-	char *p = malloc (strlen (CONFIG_FILE) + strlen (val) + 2);
+	char * p = malloc (strlen (CONFIG_FILE) + strlen (val) + 2);
 	if (p == NULL)
 	  goto Malloc_Error;
 
@@ -244,12 +261,13 @@ main (int argc, char *argv[])
    /* parse the command line */
    for (i = 1; i < argc; i += 2)
      {
-	opt = argv[i];
-	val = argv[i+1];
+	opt = argv [i];
+	val = argv [i+1];
 
 	switch (*opt++) {
 	 case '-':
 	   break;
+
 	 case '#':
 #ifdef ICONWIN
 	   rs_iconGeometry = opt;   /* drop */
@@ -262,7 +280,7 @@ main (int argc, char *argv[])
 	if (*opt == 'd')	display_name = val;	/* "d", "display" */
 	else if (*opt == 'g')	rs_geometry = val;	/* "g", "geometry" */
 #ifdef ICONWIN
-	else if (*opt == 'i' && *(opt+1) == 'c')	/* "ic", "iconic" */
+	else if (*opt == 'i')	/* "ic", "iconic" */
 	  {
 	     iconic_state = IconicState;
 	     i--;	/* no argument */
@@ -282,7 +300,7 @@ main (int argc, char *argv[])
 	       clockUpdate = x;
 	  }
 #ifdef MAIL
-	else if (!strncmp (opt, "mail", 4))
+	else if (!strcmp (opt, "mail"))
 	  {
 	     int x = atoi (val);
 	     if (x < 1)
@@ -291,6 +309,18 @@ main (int argc, char *argv[])
 	       mailUpdate = x;
 	  }
 #endif	/* MAIL */
+#ifdef ADJUST_TIME
+	else if (!strcmp (opt, "adjust"))
+	  {
+	     /* convert ddhhmm to seconds, minimal error checking */
+	     int x = atoi (val);
+	     adjustTime = ((((abs (x) / 10000) % 100) * 24	/* days */
+			    + ((abs (x) / 100) % 100)) * 60	/* hours */
+			   + (abs (x) % 100)) * 60;		/* minutes */
+	     if (x < 0)
+	       adjustTime = -adjustTime;
+	  }
+#endif	/* ADJUST_TIME */
 	else
 	  {
 	     usage ();
@@ -373,7 +403,7 @@ main (int argc, char *argv[])
  * translate geometry string to appropriate sizehint
  */
 static void
-geometry2sizehint (mywindow_t *win, const char *geom)
+geometry2sizehint (mywindow_t * win, const char * geom)
 {
    int x, y, flags;
    unsigned int width, height;
@@ -429,14 +459,13 @@ geometry2sizehint (mywindow_t *win, const char *geom)
  * Open and map the windows
  */
 static void
-Create_Windows (int argc, char *argv[])
+Create_Windows (int argc, char * argv [])
 {
    XClassHint classHint;
    XWMHints wmHint;
-   Window root = DefaultRootWindow (Xdisplay);
 
    geometry2sizehint (&Clock, rs_geometry);
-   Clock.win = XCreateSimpleWindow (Xdisplay, root,
+   Clock.win = XCreateSimpleWindow (Xdisplay, Xroot,
 				    szHint.x, szHint.y,
 				    Clock.width, Clock.height,
 				    0,
@@ -445,7 +474,7 @@ Create_Windows (int argc, char *argv[])
 
 #ifdef ICONWIN
    geometry2sizehint (&Icon, rs_iconGeometry);
-   Icon.win = XCreateSimpleWindow (Xdisplay, root,
+   Icon.win = XCreateSimpleWindow (Xdisplay, Xroot,
 				   szHint.x, szHint.y,
 				   Icon.width, Icon.height,
 				   0,
@@ -476,7 +505,7 @@ Create_Windows (int argc, char *argv[])
 
    /* create, but don't map a window for appointment reminders */
 #ifdef REMINDERS
-   Msg.win = XCreateSimpleWindow (Xdisplay, root,
+   Msg.win = XCreateSimpleWindow (Xdisplay, Xroot,
 				  szHint.x, szHint.y,
 				  szHint.width, szHint.height,
 				  0,
@@ -536,7 +565,7 @@ Create_Windows (int argc, char *argv[])
 }
 
 static time_t
-mk_time (struct tm *tmval)
+mk_time (struct tm * tmval)
 {
    return (tmval->tm_min
 	   + 60 * (tmval->tm_hour
@@ -547,32 +576,32 @@ mk_time (struct tm *tmval)
 
 /*----------------------------------------------------------------------*
  * Redraw the whole window after an exposure or size change.
- * Redraw only the hands after a timeout.
+ * After a timeout, only redraw the hands.
  * Provide reminder if needed.
  *----------------------------------------------------------------------*/
 static void
-Draw_Window (mywindow_t *W, int full_redraw)
+Draw_Window (mywindow_t * W, int full_redraw)
 {
    /* pre-computed values for sin() x1000, to avoid using floats */
    static const short Sin [60] = {
       0,
-	105, 208, 309, 407, 500, 588, 669,
-	743, 809, 866, 914, 951, 978, 995,
+      105, 208, 309, 407, 500, 588, 669,
+      743, 809, 866, 914, 951, 978, 995,
       1000,
-	995, 978, 951, 914, 866, 809, 743,
-	669, 588, 500, 407, 309, 208, 105,
+      995, 978, 951, 914, 866, 809, 743,
+      669, 588, 500, 407, 309, 208, 105,
       0,
-	-105, -208, -309, -407, -500, -588, -669,
-	-743, -809, -866, -914, -951, -978, -995,
+      -105, -208, -309, -407, -500, -588, -669,
+      -743, -809, -866, -914, -951, -978, -995,
       -1000,
-	-995, -978, -951, -914, -866, -809, -743,
-	-669, -588, -500, -407, -309, -208, -105
+      -995, -978, -951, -914, -866, -809, -743,
+      -669, -588, -500, -407, -309, -208, -105
    };
 
-   static int saved_day = -1;
+   static int savedDay = -1;
 
    time_t currentTime;
-   struct tm *tmval;
+   struct tm * tmval;
    int ctr_x, ctr_y;
 
    typedef struct {
@@ -581,7 +610,7 @@ Draw_Window (mywindow_t *W, int full_redraw)
       int s_x, s_y;		/* second */
    } hands_t;			/* hand positions (x,y) */
 
-   hands_t HandsNow, *pHandsOld;
+   hands_t HandsNow, * pHandsOld;
 
    GC X_gc, X_rvgc;
 
@@ -592,13 +621,19 @@ Draw_Window (mywindow_t *W, int full_redraw)
 #ifdef REMINDERS
    static int lastUpdateTime = -10;
 #endif
+
 #ifdef MAIL
    static time_t mailTime = 0;
    static int MailUp = 0, MailUp_rvideo = 0;
 #ifdef ICONWIN
    static int MailUp_icon = 0;
 #endif
+#endif	/* MAIL */
 
+   currentTime = time (NULL) + adjustTime;	/* get the current time */
+   tmval = localtime (&currentTime);
+
+#ifdef MAIL
 #ifdef REMINDERS
    if (W->win != Msg.win)
 #endif
@@ -609,7 +644,7 @@ Draw_Window (mywindow_t *W, int full_redraw)
 #endif
 			 &MailUp);
 
-	if (time (NULL) - mailTime >= mailUpdate)
+	if ((currentTime - mailTime) >= mailUpdate)
 	  {
 	     struct stat st;
 
@@ -645,22 +680,19 @@ Draw_Window (mywindow_t *W, int full_redraw)
 #ifdef ICONWIN
 	     if (MailUp == MailUp_icon)
 #endif
-	       mailTime = time (NULL);
+	       mailTime = currentTime;
 
 	     MailUp_rvideo = *pMailUp;
 	  }
      }
 #endif	/* MAIL */
 
-   currentTime = time (NULL);		/* get the current time */
-   tmval = localtime (&currentTime);
-
    /* once every day, update the window and icon name */
-   if (tmval->tm_yday != saved_day)
+   if (tmval->tm_yday != savedDay)
      {
 	char str [20];
 
-	saved_day = tmval->tm_yday;
+	savedDay = tmval->tm_yday;
 	strftime (str, sizeof(str), "%a %h %d", tmval);
 	XStoreName (Xdisplay, Clock.win, str);
 	XSetIconName (Xdisplay, Clock.win, str);
@@ -673,7 +705,7 @@ Draw_Window (mywindow_t *W, int full_redraw)
    /* for a message window, just re-draw the message */
    if (W->win == Msg.win)
      {
-	char *beg, *next;
+	char * beg, * next;
 	int lines;
 
 	for (beg = message, lines = 0; beg; beg = next, lines++)
@@ -717,7 +749,7 @@ Draw_Window (mywindow_t *W, int full_redraw)
 		     Xfont->ascent + 2,
 		     "Start", 5);
 
-        if (strlen (exec_prgm) > 1)
+        if (strlen (execPrgm) > 1)
 	  XMapWindow (Xdisplay, msgButton.Start);
         else
 	  XUnmapWindow (Xdisplay, msgButton.Start);
@@ -753,23 +785,22 @@ Draw_Window (mywindow_t *W, int full_redraw)
    ctr_x = (W->width  / 2);
    ctr_y = (W->height / 2);
 
-#define XPOS(i,val) (ctr_x + (W->width  * Sin[i] * (val) + 100000) / 200000)
-#define YPOS(i,val) (ctr_y - (W->height * Sin[((i)+15)%60] * (val) + 100000) / 200000)
-
+#define XPOS(i,val) (ctr_x + (W->width  * Sin[i%60] * (val) + 100000) / 200000)
+#define YPOS(i,val) (ctr_y - (W->height * Sin[(i+15)%60] * (val) + 100000) / 200000)
    /*
     * how to draw the clock face
     */
 
    /* calculate the positions of the hands */
      {
-	int angle = (tmval->tm_hour % 12) * 5 + tmval->tm_min / 12;
+	int angle = (tmval->tm_hour % 12) * 5 + (tmval->tm_min / 12);
 	HandsNow.h_x = XPOS (angle, 60);
 	HandsNow.h_y = YPOS (angle, 60);
      }
      {
 	int angle = tmval->tm_min;
-	HandsNow.m_x = XPOS (angle, 85);
-	HandsNow.m_y = YPOS (angle, 85);
+	HandsNow.m_x = XPOS (angle, 80);
+	HandsNow.m_y = YPOS (angle, 80);
      }
    if (clockUpdate == 1)
      {
@@ -806,8 +837,8 @@ Draw_Window (mywindow_t *W, int full_redraw)
 #ifdef SUBTICKS
 	for (angle = 0; angle < 60; angle++)
 	  XDrawPoint (Xdisplay, W->win, X_gc,
-		      XPOS (angle, 92),
-		      YPOS (angle, 92));
+		      XPOS (angle, 95),
+		      YPOS (angle, 95));
 #endif
 	for (angle = 0; angle < 60; angle += 5)
 	  XDrawLine (Xdisplay, W->win, X_gc,
@@ -878,7 +909,7 @@ Draw_Window (mywindow_t *W, int full_redraw)
  * DELIM = trailing delimiter to skip
  */
 static int
-GetOneNum (char **pstr, int def)
+GetOneNum (char ** pstr, int def)
 {
    int num, hit = 0;
 
@@ -899,9 +930,9 @@ GetOneNum (char **pstr, int def)
  * find if TODAY is found in PSTR
  */
 static int
-isToday (char **pstr, int wday)
+isToday (char ** pstr, int wday)
 {
-   const char *dayNames = DAY_NAMES;
+   const char * dayNames = DAY_NAMES;
    int rval, today;
 
    today = dayNames [wday];
@@ -932,6 +963,32 @@ trim_string (char * str)
    return str;
 }
 
+# ifndef NO_REMINDER_EXEC
+static char *
+extract_program (char * text)
+{
+   char * prgm = text;
+   while ((prgm = strchr (prgm, ';')) != NULL)
+     {
+	if (*(prgm-1) == '\\')    /* backslash escaped */
+	  {
+	     /* remove backslash - avoid memmove() */
+	     int i, n = strlen (prgm);
+	     for (i = 0; i <= n; i++)
+	       prgm [i - 1] = prgm [i];
+	  }
+	else
+	  {
+	     *prgm++ = '\0';
+	     /* remove leading/trailing space */
+	     prgm = trim_string (prgm);
+	     break;
+	  }
+     }
+   return prgm;
+}
+# endif	/* NO_REMINDER_EXEC */
+
 /*
  * Read the ~/.rclock file and find the next reminder
  *
@@ -946,14 +1003,14 @@ trim_string (char * str)
 static void
 Next_Reminder (int update_only)
 {
-   struct tm *tmval;
+   struct tm * tmval;
    char buffer [256];
 #ifndef INT_MAX
-#  define INT_MAX	1e8
+# define INT_MAX	1e8
 #endif
    time_t currentTime;
    int savedTime = INT_MAX;
-   FILE *fd;
+   FILE * fd;
 
    if (reminders_file == NULL || (fd = fopen (reminders_file, "r")) == NULL)
      {
@@ -961,27 +1018,45 @@ Next_Reminder (int update_only)
 	return;
      }
 
-   /* get the current time */
-   currentTime = time (NULL);
+   currentTime = time (NULL) + adjustTime;	/* get the current time */
    tmval = localtime (&currentTime);
    currentTime = mk_time (tmval);
 
-   /* initial startup, discard reminders that have already occurred */
+   /* initial startup*/
    if (reminderTime < 0)
-     reminderTime = currentTime;
+     {
+	/* ignore reminders that have already occurred */
+	reminderTime = currentTime;
+# ifndef NO_REMINDER_EXEC
+	/* scan for programs run on start-up */
+	while (fgets (buffer, sizeof(buffer), fd))
+	  {
+	     char * prgm, * text;
+
+	     text = trim_string (buffer);
+	     if (*text != ';') continue;
+
+	     prgm = extract_program (text);
+	     if (prgm != NULL && strlen (prgm) > 1)
+	       system (prgm);
+	  }
+	rewind (fd);
+# endif /* NO_REMINDER_EXEC */
+     }
 
    /* now scan for next reminder */
    while (fgets (buffer, sizeof(buffer), fd))
      {
-	char *text = buffer;
 	int testTime, hh, mm, mo, dd, yy;
+	char * text;
 
+	text = trim_string (buffer);
+	if (*text == '#') continue;	/* comment */
+	if (*text == ';') continue;	/* program run on startup */
 	/*
 	 * parse the line, format is hh:mm mo/dd/yr message; program
 	 * any of hh, mm, mo, dd, yr could be a wildcard `*'
 	 */
-	while (isspace (*text)) text++;
-	if (*text == '#') continue;	/* comment */
 	hh = GetOneNum (&text, tmval->tm_hour);  if (*text == ':') text++;
 	mm = GetOneNum (&text, 0);
 
@@ -993,6 +1068,12 @@ Next_Reminder (int update_only)
 	dd = GetOneNum (&text, tmval->tm_mday);  if (*text == '/') text++;
 	yy = GetOneNum (&text, tmval->tm_year);
 
+	/* handle 20th/21st centuries */
+	if (yy > CENTURY)
+	  yy -= 1900;
+	else if (yy < CENTURY)
+	  yy += (CENTURY - 1900);
+
 	while (isspace (*text)) text++;
 	if (!*text) continue;
 
@@ -1001,25 +1082,8 @@ Next_Reminder (int update_only)
 	if (testTime > (update_only ? currentTime : reminderTime))
 	  {
 #ifndef NO_REMINDER_EXEC
-	     char * prgm;
-	     for (prgm = text; (prgm = strchr (prgm, ';')) != NULL; prgm++)
-	       {
-		  if (*(prgm-1) == '\\')    /* backslash escaped */
-		    {
-		       /* remove backslash - avoid memmove() */
-		       int i, n = strlen (--prgm);
-		       for (i = 0; i < n; i++)
-			 prgm [i] = prgm [i + 1];
-		    }
-		  else
-		    {
-		       *prgm++ = '\0';
-		       /* remove leading/trailing space */
-		       prgm = trim_string (prgm);
-		       break;
-		    }
-	       }
-#endif /* NO_REMINDER_EXEC */
+	     char * prgm = extract_program (text);
+#endif	/* NO_REMINDER_EXEC */
 	     /* trim leading/trailing space */
 	     text = trim_string (text);
 
@@ -1032,36 +1096,37 @@ Next_Reminder (int update_only)
 		  savedTime = testTime;
 		  strncpy (message, text, sizeof(message));
 #ifndef NO_REMINDER_EXEC
-                  if (prgm != NULL)
-		    strncpy (exec_prgm, prgm, sizeof(exec_prgm));
-		  else
-		    exec_prgm [0] = '\0';
+		  strncpy (execPrgm, (prgm ? prgm : ""), sizeof(execPrgm));
 #endif
 	       }
 	     else if (testTime == savedTime)
 	       {
-		  int n = (sizeof(message) - strlen (message) - 3);
-		  if (n > 0)
+                  if (strlen (text))
 		    {
-		       /* for co-occurring events */
-		       strcat (message, "\\n");
-		       strncat (message, text, n);
+		       int n = (sizeof(message) - strlen (message) - 3);
+		       if (n > 0)
+			 {
+			    /* for co-occurring events */
+			    strcat (message, "\\n");
+			    strncat (message, text, n);
+			 }
 		    }
 #ifndef NO_REMINDER_EXEC
                   if (prgm != NULL)
 		    {
-		       n = (sizeof(exec_prgm) - strlen (exec_prgm) - 2);
+		       int n = (sizeof(execPrgm) - strlen (execPrgm) - 2);
 		       if ((n > 0) && (n >= strlen (prgm)))
 			 {
 			    /* for co-occurring programs */
-			    strcat (exec_prgm, ";");
-			    strncat (exec_prgm, prgm, n);
+			    strcat (execPrgm, ";");
+			    strncat (execPrgm, prgm, n);
 			 }
 		    }
 #endif /* NO_REMINDER_EXEC */
 	       }
 	  }
      }
+
    reminderTime = (savedTime < INT_MAX) ? savedTime : -1;
    fclose (fd);
 }
@@ -1072,7 +1137,7 @@ Next_Reminder (int update_only)
 static void
 Reminder (void)
 {
-   char *beg, *next;
+   char * beg, * next;
    int lines;
 
    if (Msg_Mapped)
@@ -1081,9 +1146,9 @@ Reminder (void)
 #ifndef NO_REMINDER_EXEC
    if (strlen (message) == 0)
      {
-	if (strlen (exec_prgm) > 1)
+	if (strlen (execPrgm) > 1)
 	  {
-	     system (exec_prgm);
+	     system (execPrgm);
 	     Next_Reminder (REPLACE);
 	  }
 	return;			/* some sort of error */
@@ -1100,7 +1165,7 @@ Reminder (void)
    for (beg = message, lines = 1; beg; beg = next, lines++)
      {
 	int width;
-	char *end;
+	char * end;
 
 	if ((end = strstr (beg, "\\n")) == NULL)
 	  {
@@ -1167,18 +1232,18 @@ getXevent (void)
    XEvent ev;
    int num_fds;		/* number of file descriptors being used */
    struct timeval tm;
-   struct tm *tmval;
-   Atom wm_del_win;
+   struct tm * tmval;
+   Atom wmDeleteWindow;
    fd_set in_fdset;
 
    /* Enable delete window protocol */
-   wm_del_win = XInternAtom (Xdisplay, "WM_DELETE_WINDOW", False);
-   XSetWMProtocols (Xdisplay, Clock.win, &wm_del_win, 1);
+   wmDeleteWindow = XInternAtom (Xdisplay, "WM_DELETE_WINDOW", False);
+   XSetWMProtocols (Xdisplay, Clock.win, &wmDeleteWindow, 1);
 #ifdef ICONWIN
-   XSetWMProtocols (Xdisplay, Icon.win,  &wm_del_win, 1);
+   XSetWMProtocols (Xdisplay, Icon.win,  &wmDeleteWindow, 1);
 #endif
 #ifdef REMINDERS
-   XSetWMProtocols (Xdisplay, Msg.win,   &wm_del_win, 1);
+   XSetWMProtocols (Xdisplay, Msg.win,   &wmDeleteWindow, 1);
 #endif
 
 #ifdef _POSIX_VERSION
@@ -1195,7 +1260,7 @@ getXevent (void)
 	  case ClientMessage:
 	    /* check for delete window requests */
 	    if ((ev.xclient.format == 32) &&
-		(ev.xclient.data.l[0] == wm_del_win))
+		(ev.xclient.data.l[0] == wmDeleteWindow))
 	      {
 #ifdef REMINDERS
 		 if (ev.xany.window == Msg.win)
@@ -1259,16 +1324,16 @@ getXevent (void)
 		   }
 		 else if (ev.xbutton.subwindow == msgButton.Defer)
 		   {
-		      time_t t = time (NULL);
+		      time_t t = time (NULL) + adjustTime;
 		      tmval = localtime (&t);
-		      reminderTime = 3 + mk_time (tmval);
+		      reminderTime = mk_time (tmval) + DEFER_TIME;
 		      Msg_Mapped = 0;
 		      XUnmapWindow (Xdisplay, Msg.win);
 		   }
 #ifndef NO_REMINDER_EXEC
                  else if (ev.xbutton.subwindow == msgButton.Start)
                    {
-		      system (exec_prgm);
+		      system (execPrgm);
                       Next_Reminder (REPLACE);
                       Msg_Mapped = 0;
                       XUnmapWindow (Xdisplay, Msg.win);
@@ -1310,7 +1375,7 @@ getXevent (void)
  * Print an error message.
  */
 static void
-print_error (const char *fmt, ...)
+print_error (const char * fmt, ...)
 {
    va_list arg_ptr;
 
