@@ -18,21 +18,42 @@
  * he guarantee anything whatsoever.
  *----------------------------------------------------------------------*/
 #ifndef _COMMAND_H
-#define _COMMAND_H
+# define _COMMAND_H
+# include <X11/Xfuncproto.h>
+# include <stdio.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-   extern void	init_command (char *argv[]);
-   extern void	tt_resize (void);
-   extern void	tt_write (const unsigned char *str, unsigned int count);
-   extern void	tt_printf (const unsigned char *fmt, ...);
-   extern void	main_loop (void);
+#define menuBar_esc	10
+#define scrollBar_esc	30
+
+_XFUNCPROTOBEGIN
+
+extern void
+init_command (char * /* argv */ []);
+
+extern void
+tt_resize (void);
+
+extern void
+tt_write (const unsigned char * /* str */,
+	  unsigned int /* count */);
+
+extern void
+tt_printf (const unsigned char * /* fmt */, ...);
+
+extern unsigned int
+cmd_write (const unsigned char * /* str */,
+	   unsigned int /* count */);
+
+extern void
+main_loop (void);
+
+extern FILE *
+popen_printer (void);
+
+extern int
+pclose_printer (FILE * /* stream */);
+
+_XFUNCPROTOEND
 
-   extern FILE * popen_printer (void);
-   extern int	pclose_printer (FILE *stream);
-#ifdef __cplusplus
-}
-#endif
 #endif	/* whole file */
 /*----------------------- end-of-file (C header) -----------------------*/
