@@ -27,7 +27,7 @@
 void *
 my_malloc (size_t size)
 {
-   void *ptr;
+   void * ptr;
    if ((ptr = malloc (size)) == NULL)
      {
 	printf ("malloc error: size 0x%X\n",
@@ -43,7 +43,7 @@ my_malloc (size_t size)
 void *
 my_calloc (size_t count, size_t size)
 {
-   void	*ptr;
+   void	* ptr;
 
    if ((ptr = calloc (count, size)) == NULL)
      {
@@ -58,9 +58,9 @@ my_calloc (size_t count, size_t size)
  * realloc and check for NULL return
  */
 void *
-my_realloc (void *mem, size_t size)
+my_realloc (void * mem, size_t size)
 {
-   void	*ptr;
+   void	* ptr;
    /*
     * do this since some implementations (Sun for one) gags on realloc with
     * a NULL pointer
@@ -74,9 +74,10 @@ my_realloc (void *mem, size_t size)
 }
 
 void
-my_free (void *mem)
+my_free (void * mem)
 {
-   if (mem) free (mem);	/* in case free() is non-compilant */
+   if (mem != NULL)		/* in case free() is non-compilant */
+     free (mem);
 }
 
 #else	/* DEBUG_MALLOC */
@@ -87,7 +88,7 @@ my_free (void *mem)
 #define PADCHAR1	0x3E
 #define PADCHAR2	0x3F
 
-static int num_alloc = 0;
+static short num_alloc = 0;
 static struct {
    void * base;
    const char * name;
@@ -98,11 +99,11 @@ static struct {
  * DEBUG_MALLOC is set
  */
 void *
-safe_malloc (size_t size, const char *id)
+safe_malloc (size_t size, const char * id)
 {
-   void *ptr;
+   void * ptr;
 #ifdef DEBUG_MALLOC
-   char *tmp;
+   char * tmp;
    int i;
 
    if ((ptr = malloc (size + 2 * NPAD * sizeof(int))) == NULL)
@@ -154,9 +155,9 @@ safe_malloc (size_t size, const char *id)
  * checking if DEBUG_MALLOC is set.
  */
 void *
-safe_calloc (size_t count, size_t size, const char *id)
+safe_calloc (size_t count, size_t size, const char * id)
 {
-   void	*ptr;
+   void	* ptr;
 
    ptr = safe_malloc (count * size, id);
    memset (ptr, 0, size);
@@ -168,9 +169,9 @@ safe_calloc (size_t count, size_t size, const char *id)
  * checking if DEBUG_MALLOC is set.
  */
 void *
-safe_realloc (void *mem, size_t size, const char *id)
+safe_realloc (void * mem, size_t size, const char * id)
 {
-   void	*ptr;
+   void	* ptr;
 
    ptr = safe_malloc (size, id);
    if (mem != NULL)
@@ -191,9 +192,9 @@ safe_realloc (void *mem, size_t size, const char *id)
  * before freeing.
  */
 void
-safe_free (void *ptr, const char *id1, const char *id2)
+safe_free (void * ptr, const char * id1, const char * id2)
 {
-   if (ptr)
+   if (ptr != NULL)
      {
 #ifdef DEBUG_MALLOC
 	/* Check each memory region */
@@ -225,11 +226,11 @@ safe_free (void *ptr, const char *id1, const char *id2)
  * Check all allocated memory for out-of-bounds memory usage
  */
 void
-safe_mem_check (const char *id1, const char *id2)
+safe_mem_check (const char * id1, const char * id2)
 {
 #ifdef DEBUG_MALLOC
    int i, fail = 0;
-   static const char *prev_id1 = NULL, *prev_id2 = NULL;
+   static const char * prev_id1 = NULL, * prev_id2 = NULL;
 
    char * msg_fmt = "Ouch%d: at 0x%08X (size %d) [idx %d]: \"%s\" (%s/%s)\n";
    char * last_chk = "Last successful check (%s/%s)\n";
@@ -247,7 +248,7 @@ safe_mem_check (const char *id1, const char *id2)
 	  continue;
 	size = *((int *) ptr + NPAD - 1);
 
-	for (j = 0; j < ((NPAD-1)*sizeof(int)); j++)
+	for (j = 0; j < ((NPAD-1) * sizeof(int)); j++)
 	  {
 	     if (ptr [j] == PADCHAR1)
 	       continue;
@@ -261,7 +262,7 @@ safe_mem_check (const char *id1, const char *id2)
 	       fprintf (stderr, last_chk, prev_id1, prev_id2);
 	  }
 
-	ptr += size + NPAD * sizeof (int);
+	ptr += size + NPAD * sizeof(int);
 	for (j = 0; j < NPAD * sizeof(int); j++)
 	  {
 	     if (ptr [j] == PADCHAR2)
