@@ -2,9 +2,9 @@
  * File:	defaults.h
  *
  * Some wired-in defaults so we can run without external resources.
- * Split from configure.h so fiddling won't require a full rebuild.
+ * Split from feature.h so fiddling won't require a full rebuild.
  *
- * These values are only used in xsetup.c
+ * These values are only used in main.c
  * ----------------------------------------------------------------------
  * Copyright 1995, 1996
  * mj olesen <olesen@me.queensu.ca> Queen's Univ at Kingston
@@ -17,30 +17,11 @@
 #ifndef _DEFAULTS_H
 #define _DEFAULTS_H
 
-/* various Keysym(s), self-explanatory */
-
-/* recognized when combined with HOTKEY */
-#define KS_BIGFONT	XK_greater
-#define KS_SMALLFONT	XK_less
-#define KS_PAGEUP	XK_Prior
-#define KS_PAGEDOWN	XK_Next
-#define KS_PASTE	XK_Insert
-
-#ifdef HOTKEY_SHIFT
-# undef KS_BIGFONT
-# undef KS_SMALLFONT
-# define KS_BIGFONT	XK_KP_Add
-# define KS_SMALLFONT	XK_KP_Subtract
-#endif
-
-/* recognized on its own */
-#define KS_PRINTSCREEN	XK_Print
-
-#define BORDERWIDTH		1	/* borderWidth [pixels] */
-#define SAVELINES		64	/* saveLines [lines] */
+#define BORDERWIDTH	1	/* borderWidth [pixels] */
+#define SAVELINES	64	/* saveLines [lines] */
 
 /* character class of separating chars for multiple-click selection */
-#define CUTCHARS		"\t `\"'&()*,;<=>?@[\\]{|}"
+#define CUTCHARS	"\t \"&'()*,;<=>?@[\\]^`{|}~"
 
 /* fonts used */
 #ifdef KANJI
