@@ -1,8 +1,8 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	xdefaults.c
  *
- * obtain resources from ~/.Xdefaults or ~/.Xresources using either
- * REAL_RESOURCES (XGetDefault) or for memory savings FAKE_RESOURCES.
+ * get resources from ~/.Xdefaults or ~/.Xresources with the memory-saving
+ * default or with XGetDefault() (#define USE_XGETDEFAULT)
  *
  * This module is all new by Rob Nation
  *
@@ -13,23 +13,26 @@
  * ---------------------------------------------------------------------*
  * Extensive modifications by mj olesen <olesen@me.QueensU.CA>
  * No additional restrictions.
+ *
+ * Coding style:
+ *	resource strings are indicated by an `rs_' prefix followed by
+ *	the resource name.
+ *	eg, `rs_saveLines' is the resource string corresponding to
+ *	    the `saveLines' resource
  *----------------------------------------------------------------------*/
+/*{{{ includes */
 #include "main.h"
 
 #include "debug.h"
+#include "defaults.h"
 #include "grkelot.h"
 #include "xdefaults.h"
+/*}}}*/
 
 /* #define DEBUG_RESOURCES */
-/*----------------------------------------------------------------------*
- * extern functions referenced
- */
-/*----------------------------------------------------------------------*
- * extern variables referenced
- */
-/*----------------------------------------------------------------------*
- * extern variables declared here
- */
+/* extern functions referenced */
+/* extern variables referenced */
+/*{{{ extern variables declared here */
 const char * rs_title = NULL;		/* title name for window */
 const char * rs_iconName = NULL;	/* icon name for window */
 const char * rs_geometry = NULL;	/* window geometry */
@@ -37,27 +40,26 @@ const char * rs_saveLines = NULL;	/* scrollback buffer [lines] */
 #ifdef KEYSYM_RESOURCE
 const unsigned char * KeySym_map [256];	/* probably mostly empty */
 #endif
+#if defined (HOTKEY_CTRL) || defined (HOTKEY_META)
+/* recognized when combined with HOTKEY */
+KeySym ks_bigfont = XK_greater;
+KeySym ks_smallfont = XK_less;
+#endif
+#ifdef XPM_BACKGROUND
+const char * rs_backgroundPixmap = NULL;
+const char * rs_path = NULL;
+#endif
+/*}}}*/
 
-/*----------------------------------------------------------------------*
- * local variables
- */
-/*----------------------------------------------------------------------*
- * local functions referenced
- */
-/*----------------------------------------------------------------------*
- * local variables
- */
+/* local functions referenced */
+/*{{{ local variables */
 static const char * rs_loginShell = NULL;
 static const char * rs_utmpInhibit = NULL;
 static const char * rs_scrollBar = NULL;
-#ifdef PRINTPIPE
-static const char * rs_printscreen_key = NULL;
-#endif
-#ifdef PASTE_KEY
-static const char * rs_paste_key = NULL;
-#endif
+#if defined (HOTKEY_CTRL) || defined (HOTKEY_META)
 static const char * rs_bigfont_key = NULL;
 static const char * rs_smallfont_key = NULL;
+#endif
 
 #ifndef NO_MAPALERT
 # ifdef MAPALERT_OPTION
@@ -75,9 +77,10 @@ static const char * rs_kanji_encoding = NULL;
 #ifdef GREEK_SUPPORT
 static const char * rs_greek_keyboard = NULL;
 #endif
+/*}}}*/
 
-/* monolithic structure option/resource structure:
- *
+/*{{{ monolithic option/resource structure: */
+/*
  * `string' options MUST have a usage argument
  * `switch' and `boolean' options have no argument
  *
@@ -91,194 +94,199 @@ static const struct {
    const char * const arg;	/* argument */
    const char * const desc;	/* description */
 } optList[] = {
+   /* INFO() - descriptive information only */
 #define INFO(opt,arg,desc)       {0, NULL, NULL, opt, arg, desc}
+   /* STRG() - command-line option, with/without resource */
 #define STRG(p,kw,opt,arg,desc)  {0, &p, kw, opt, arg, desc}
+   /* RSTRG() - resource/long-option */
 #define RSTRG(p,kw,arg)          {0, &p, kw, NULL, arg, NULL}
-#define SWCH(opt,flag,desc)      {(flag), NULL, NULL, opt, NULL, desc}
+   /* BOOL() - regular boolean `-/+' flag */
 #define BOOL(p,kw,opt,flag,desc) {(Opt_Boolean|flag), &p, kw, opt, NULL, desc}
+   /* SWCH() - `-' flag */
+#define SWCH(opt,flag,desc)      {(flag), NULL, NULL, opt, NULL, desc}
+   /* convenient macros */
 #define optList_strlen(i) (optList[i].flag ? 0 : (optList[i].arg ? strlen (optList[i].arg) : 1))
 #define optList_isBool(i) (optList[i].flag & Opt_Boolean)
 #define optList_size()    (sizeof(optList)/sizeof(optList[0]))
-     STRG(
-	  display_name,
-	  NULL,
-	  "display", "displayname", "X server to contact" ),
-     STRG(
-	  rs_geometry,
-	  "geometry",
-	  "geometry", "geom", "size (in characters) and position" ),
-     STRG( display_name, NULL, "d", NULL, NULL ),	/* short form */
-     STRG( rs_geometry, NULL, "g", NULL, NULL ), 	/* short form */
-     BOOL(
-	  rs_reverseVideo,
-	  "reverseVideo",
-	  "rv", Opt_reverseVideo, "reverse video" ),
-     STRG(
-	  rs_color [bgColor],
-	  "background",
-	  "bg", "color", "background color" ),
-     STRG(
-	  rs_color [fgColor],
-	  "foreground",
-	  "fg", "color", "foreground color" ),
-     /* colors: command-line option = resource name */
-     RSTRG( rs_color [minColor+0],  "color0", "color" ),
-     RSTRG( rs_color [minColor+1],  "color1", "color" ),
-     RSTRG( rs_color [minColor+2],  "color2", "color" ),
-     RSTRG( rs_color [minColor+3],  "color3", "color" ),
-     RSTRG( rs_color [minColor+4],  "color4", "color" ),
-     RSTRG( rs_color [minColor+5],  "color5", "color" ),
-     RSTRG( rs_color [minColor+6],  "color6", "color" ),
-     RSTRG( rs_color [minColor+7],  "color7", "color" ),
+   STRG(
+	display_name,
+	NULL,
+	"display", "displayname", "X server to contact" ),
+   STRG(
+	rs_geometry,
+	"geometry",
+	"geometry", "geom", "size (in characters) and position" ),
+   STRG( display_name, NULL, "d", NULL, NULL ),	/* short form */
+   STRG( rs_geometry, NULL, "g", NULL, NULL ), 	/* short form */
+   BOOL(
+	rs_reverseVideo,
+	"reverseVideo",
+	"rv", Opt_reverseVideo, "reverse video" ),
+   STRG(
+	rs_color [bgColor],
+	"background",
+	"bg", "color", "background color" ),
+   STRG(
+	rs_color [fgColor],
+	"foreground",
+	"fg", "color", "foreground color" ),
+   /* colors: command-line long-option = resource name */
+   RSTRG( rs_color [minColor+0],  "color0", "color" ),
+   RSTRG( rs_color [minColor+1],  "color1", "color" ),
+   RSTRG( rs_color [minColor+2],  "color2", "color" ),
+   RSTRG( rs_color [minColor+3],  "color3", "color" ),
+   RSTRG( rs_color [minColor+4],  "color4", "color" ),
+   RSTRG( rs_color [minColor+5],  "color5", "color" ),
+   RSTRG( rs_color [minColor+6],  "color6", "color" ),
+   RSTRG( rs_color [minColor+7],  "color7", "color" ),
 #ifndef NO_BRIGHTCOLOR
-     RSTRG( rs_color [minBright+0], "color8",  "color" ),
-     RSTRG( rs_color [minBright+1], "color9",  "color" ),
-     RSTRG( rs_color [minBright+2], "color10", "color" ),
-     RSTRG( rs_color [minBright+3], "color11", "color" ),
-     RSTRG( rs_color [minBright+4], "color12", "color" ),
-     RSTRG( rs_color [minBright+5], "color13", "color" ),
-     RSTRG( rs_color [minBright+6], "color14", "color" ),
-     RSTRG( rs_color [minBright+7], "color15", "color" ),
+   RSTRG( rs_color [minBright+0], "color8",  "color" ),
+   RSTRG( rs_color [minBright+1], "color9",  "color" ),
+   RSTRG( rs_color [minBright+2], "color10", "color" ),
+   RSTRG( rs_color [minBright+3], "color11", "color" ),
+   RSTRG( rs_color [minBright+4], "color12", "color" ),
+   RSTRG( rs_color [minBright+5], "color13", "color" ),
+   RSTRG( rs_color [minBright+6], "color14", "color" ),
+   RSTRG( rs_color [minBright+7], "color15", "color" ),
 #endif	/* NO_BRIGHTCOLOR */
 #ifndef NO_BOLDUNDERLINE
-     RSTRG( rs_color [colorBD], "colorBD", "color" ),
-     RSTRG( rs_color [colorUL], "colorUL", "color" ),
+   RSTRG( rs_color [colorBD], "colorBD", "color" ),
+   RSTRG( rs_color [colorUL], "colorUL", "color" ),
 #endif	/* NO_BOLDUNDERLINE */
 #ifndef XTERM_SCROLLBAR
-     RSTRG( rs_color [scrollColor],       "scrollColor",    "color"),
+   RSTRG( rs_color [scrollColor],       "scrollColor",    "color"),
 #endif	/* XTERM_SCROLLBAR */
-
-#ifdef USE_BOLDFONT
-     STRG(
-	  rs_boldFont,
-	  "boldFont",
-	  "fb", "fontname", "bold text font" ),
+#ifdef XPM_BACKGROUND
+   STRG( rs_backgroundPixmap,
+	"backgroundPixmap",
+	"pixmap", "file[;geom]", "background pixmap [scaling optional]" ),
+   RSTRG( rs_path, "path", "search path" ),
+#endif	/* XPM_BACKGROUND */
+#ifndef NO_BOLDFONT
+   STRG(
+	rs_boldFont,
+	"boldFont",
+	"fb", "fontname", "bold text font" ),
 #endif
-     STRG(
-	  rs_font [0],
-	  "font",
-	  "fn", "fontname", "normal text font" ),
-     /* fonts: command-line option = resource name */
-     RSTRG( rs_font [1], "font1", "fontname" ),
-     RSTRG( rs_font [2], "font2", "fontname" ),
-     RSTRG( rs_font [3], "font3", "fontname" ),
-     RSTRG( rs_font [4], "font4", "fontname" ),
+   STRG(
+	rs_font [0],
+	"font",
+	"fn", "fontname", "normal text font" ),
+   /* fonts: command-line option = resource name */
+   RSTRG( rs_font [1], "font1", "fontname" ),
+   RSTRG( rs_font [2], "font2", "fontname" ),
+   RSTRG( rs_font [3], "font3", "fontname" ),
+   RSTRG( rs_font [4], "font4", "fontname" ),
 #ifdef KANJI
-     STRG(
-	  rs_kfont [0],
-	  "kfont",
-	  "fk", "fontname", "kanji font" ),
+   STRG(
+	rs_kfont [0],
+	"kfont",
+	"fk", "fontname", "kanji font" ),
 
-     /* fonts: command-line option = resource name */
-     RSTRG( rs_kfont [1], "kfont1", "fontname" ),
-     RSTRG( rs_kfont [2], "kfont2", "fontname" ),
-     RSTRG( rs_kfont [3], "kfont3", "fontname" ),
-     RSTRG( rs_kfont [4], "kfont4", "fontname" ),
+   /* fonts: command-line option = resource name */
+   RSTRG( rs_kfont [1], "kfont1", "fontname" ),
+   RSTRG( rs_kfont [2], "kfont2", "fontname" ),
+   RSTRG( rs_kfont [3], "kfont3", "fontname" ),
+   RSTRG( rs_kfont [4], "kfont4", "fontname" ),
 
-     STRG(
-	  rs_kanji_encoding,
-	  "kanji_encoding",
-	  "km", "mode", "kanji encoding; mode = eucj | sjis" ),
+   STRG(
+	rs_kanji_encoding,
+	"kanji_encoding",
+	"km", "mode", "kanji encoding; mode = eucj | sjis" ),
 #endif	/* KANJI */
 #ifdef GREEK_SUPPORT
-     STRG(
-	  rs_greek_keyboard,
-	  "greek_keyboard",
-	  "grk", "mode", "greek keyboard mapping; mode = iso | ibm" ),
+   STRG(
+	rs_greek_keyboard,
+	"greek_keyboard",
+	"grk", "mode", "greek keyboard mapping; mode = iso | ibm" ),
 #endif
-     SWCH( "iconic", Opt_iconic, "start iconic" ),
-     SWCH( "ic", Opt_iconic, NULL ),	/* short form */
-     STRG(
-	  rs_name,
-	  NULL,
-	  "name", "string", "client instance, icon, and title strings" ),
-     STRG(
-	  rs_title,
-	  "title",
-	  "title", "string", "title name for window" ),
-     STRG( rs_title, NULL, "T", NULL, NULL ),  /* short form */
-     STRG(
-	  rs_iconName,
-	  "iconName",
-	  "n", "string", "icon name for window" ),
+   SWCH( "iconic", Opt_iconic, "start iconic" ),
+   SWCH( "ic", Opt_iconic, NULL ),	/* short form */
+   STRG(
+	rs_name,
+	NULL,
+	"name", "string", "client instance, icon, and title strings" ),
+   STRG(
+	rs_title,
+	"title",
+	"title", "string", "title name for window" ),
+   STRG( rs_title, NULL, "T", NULL, NULL ),  /* short form */
+   STRG(
+	rs_iconName,
+	"iconName",
+	"n", "string", "icon name for window" ),
 #ifndef NO_CURSORCOLOR
-     STRG(
-	  rs_color [cursorColor],
-	  "cursorColor",
-	  "cr", "color", "cursor color" ),
-     /* command-line option = resource name */
-     RSTRG( rs_color [cursorColor2], "cursorColor2", "color" ),
+   STRG(
+	rs_color [cursorColor],
+	"cursorColor",
+	"cr", "color", "cursor color" ),
+   /* command-line option = resource name */
+   RSTRG( rs_color [cursorColor2], "cursorColor2", "color" ),
 #endif	/* NO_CURSORCOLOR */
-     BOOL(
-	  rs_loginShell,
-	  "loginShell",
-	  "ls", Opt_loginShell, "login shell" ),
-     BOOL(
-	  rs_scrollBar,
-	  "scrollBar",
-	  "sb", Opt_scrollBar, "scrollbar" ),
-     STRG(
-	  rs_saveLines,
-	  "saveLines",
-	  "sl", "number", "number of scrolled lines to save" ),
-     BOOL(
-	  rs_utmpInhibit,
-	  "utmpInhibit",
-	  "ut", Opt_utmpInhibit, "utmp inhibit" ),
-     BOOL(
-	  rs_visualBell,
-	  "visualBell",
-	  "vb", Opt_visualBell, "visual bell" ),
-
+   BOOL(
+	rs_loginShell,
+	"loginShell",
+	"ls", Opt_loginShell, "login shell" ),
+   BOOL(
+	rs_scrollBar,
+	"scrollBar",
+	"sb", Opt_scrollBar, "scrollbar" ),
+   STRG(
+	rs_saveLines,
+	"saveLines",
+	"sl", "number", "number of scrolled lines to save" ),
+   BOOL(
+	rs_utmpInhibit,
+	"utmpInhibit",
+	"ut", Opt_utmpInhibit, "utmp inhibit" ),
+   BOOL(
+	rs_visualBell,
+	"visualBell",
+	"vb", Opt_visualBell, "visual bell" ),
 #ifndef NO_MAPALERT
 # ifdef MAPALERT_OPTION
-     BOOL(
-	  rs_mapAlert,
-	  "mapAlert",
-	  NULL, Opt_mapAlert, NULL ),
+   BOOL(
+	rs_mapAlert,
+	"mapAlert",
+	NULL, Opt_mapAlert, NULL ),
 # endif
 #endif
 #ifdef META8_OPTION
-     BOOL(
-	  rs_meta8,
-	  "meta8",
-	  NULL, Opt_meta8, NULL ),
+   BOOL(
+	rs_meta8,
+	"meta8",
+	NULL, Opt_meta8, NULL ),
 #endif
 
 #ifdef PRINTPIPE
-     RSTRG( rs_print_pipe, "print-pipe", "string" ),
+   RSTRG( rs_print_pipe, "print-pipe", "string" ),
 #endif
 
-#ifdef PRINTPIPE
-     RSTRG( rs_printscreen_key, "printscreen_key", "keysym" ),
+#if defined (HOTKEY_CTRL) || defined (HOTKEY_META)
+   RSTRG( rs_bigfont_key,   "bigfont_key", "keysym" ),
+   RSTRG( rs_smallfont_key, "smallfont_key", "keysym" ),
 #endif
-#ifdef PASTE_KEY
-     RSTRG( rs_paste_key, "paste_key", "keysym" ),
-#endif
-
-     RSTRG( rs_bigfont_key,   "bigfont_key", "keysym" ),
-     RSTRG( rs_smallfont_key, "smallfont_key", "keysym" ),
-#ifndef NO_MULTIPLE_CLICK
 #ifdef CUTCHAR_RESOURCE
-     RSTRG( rs_cutchars, "cutchars", "string" ),
+   RSTRG( rs_cutchars, "cutchars", "string" ),
 #endif	/* CUTCHAR_RESOURCE */
-#endif	/* NO_MULTIPLE_CLICK */
 
-     SWCH( "C", Opt_console, "intercept console messages" ),
-     INFO( "e", "command arg ...", "command to execute" )
+   SWCH( "C", Opt_console, "intercept console messages" ),
+   INFO( "e", "command arg ...", "command to execute" )
 };
 #undef INFO
 #undef STRG
 #undef RSTRG
 #undef SWCH
 #undef BOOL
+/*}}}*/
 
+/*{{{ usage: */
 /*----------------------------------------------------------------------*/
 static void
 usage (int type)
 {
    int i, col;
-#define INDENT 25
+#define INDENT 30
 
    fprintf (stderr, "\nUsage v"VERSION":\n  " APL_NAME);
    switch (type) {
@@ -351,16 +359,14 @@ usage (int type)
       fprintf (stderr, "    " "keysym.sym" ": %*s\n",
 	       (INDENT - strlen ("keysym.sym")), "keysym");
 #endif
-      fprintf (stderr, "\n");
+      fprintf (stderr, "\n    -help to list options\n\n");
       break;
    }
    exit (EXIT_FAILURE);
 }
+/*}}}*/
 
-/*
- * get all command-line option (string and boolean)
- * before getting resources
- */
+/*{{{ get command-line options before getting resources */
 void
 get_options (int argc, char * argv[])
 {
@@ -396,9 +402,9 @@ get_options (int argc, char * argv[])
 
         if (!strcmp (opt, "help")) usage (longopt ? 2 : 1);
 
+	/* feature: always try to match long-options */
         for (entry = 0; entry < optList_size (); entry++)
-	  if ((longopt &&
-	       optList[entry].kw && !strcmp (opt, optList[entry].kw)) ||
+	  if ((optList[entry].kw && !strcmp (opt, optList[entry].kw)) ||
 	      (!longopt &&
 	       optList[entry].opt && !strcmp (opt, optList[entry].opt)))
 	    break;
@@ -476,13 +482,16 @@ get_options (int argc, char * argv[])
    if (bad_option)
      usage (0);
 }
+/*}}}*/
 
 #ifndef NO_RESOURCES
+/*----------------------------------------------------------------------*/
+/*{{{ string functions */
 /*
  * a replacement for strcasecmp() to avoid linking an entire library
  */
 static int
-my_strcasecmp (const char *s1, const char *s2)
+my_strcasecmp (const char * s1, const char * s2)
 {
    for (/*nil*/; (*s1 && *s2); s1++, s2++)
      {
@@ -493,64 +502,13 @@ my_strcasecmp (const char *s1, const char *s2)
      }
    return (int) (*s1 - *s2);
 }
+/*}}}*/
 
-/*----------------------------------------------------------------------*/
-/*
- * interprete backslash-escaped strings
- */
-#ifdef KEYSYM_RESOURCE
-static char *
-escaped_string (char * str)
-{
-   register char * p;
-   int i, len;
-
-   if (str == NULL || (len = strlen (str)) == 0)
-     return NULL;
-
-   /* use 'i' to increment through destination and p through source */
-   for (p = str, i = 0; i < len; i++)
-     {
-	register char ch = *p++;
-	if (ch == '\\')
-	  {
-	     ch = *p;
-	     if (isdigit (ch))	/* octal */
-	       {
-		  int j, num = 0;
-		  for (j = 0; j < 3 && (ch >= '0' && ch <= '7'); j++)
-		    {
-		       num = num * 010 + (ch - '0');
-		       p++; len--;
-		       ch = *p;
-		    }
-		  ch = (unsigned char) num;
-	       }
-	     else
-	       {
-		  p++; len--;		/* one fewer char */
-		  switch (ch) {
-		   case 'b': ch = '\b';	break;	/* backspace */
-		   case 'E':
-		   case 'e': ch =  033;	break;	/* escape */
-		   case 'n': ch = '\n';	break;	/* newline */
-		   case 'r': ch = '\r';	break;	/* carriage-return */
-		   case 't': ch = '\t';	break;	/* tab */
-		  }
-	       }
-	  }
-	str [i] = ch;
-     }
-   str [len] = '\0';
-
-   return strlen (str) ? str : NULL;
-}
-#endif	/* KEYSYM_RESOURCE */
-
+#ifndef USE_XGETDEFAULT
+/*{{{ more string functions */
 /*
  * remove leading/trailing space and strip-off leading/trailing quotes
  */
-#ifdef FAKE_RESOURCES
 static char *
 trim_string (char * str)
 {
@@ -574,9 +532,10 @@ trim_string (char * str)
      }
    return str;
 }
-
+/*}}}*/
+/*{{{ get_xdefaults() */
 /*
- * the matching algorithm used for FAKE_RESOURCES
+ * the matching algorithm used for memory-save fake resources
  */
 static void
 get_xdefaults (FILE * stream, const char * name)
@@ -592,7 +551,7 @@ get_xdefaults (FILE * stream, const char * name)
 
 	while (*str && isspace (*str)) str++;    /* leading whitespace */
 
-	if (((str [len] != '*' && str [len] != '.')) ||
+	if ((str [len] != '*' && str [len] != '.') ||
 	    (len && strncmp (str, name, len)))
 	  continue;
 	str += (len + 1);	/* skip `name*' or `name.' */
@@ -603,7 +562,7 @@ get_xdefaults (FILE * stream, const char * name)
 	 */
 # ifdef KEYSYM_RESOURCE
 	n = strlen ("keysym");
-	if ((str [n] == '.') && !strncmp (str, "keysym", n))
+	if (str [n] == '.' && !strncmp (str, "keysym", n))
 	  {
 	     int sym;
 	     str += (n + 1);	/* skip `keysym.' */
@@ -614,17 +573,19 @@ get_xdefaults (FILE * stream, const char * name)
 	       {
 		  /* cue to ':', it's there since sscanf() worked */
 		  str = strchr (str, ':');
-		  str = escaped_string (trim_string (str + 1));
+		  str = trim_string (str + 1);
+		  n = escaped_string (str);
 
 		  /* only do extended keys */
 		  if (sym >= 0xFF00) sym -= 0xFF00;
 		  if (sym < 0 || sym > 0xFF) continue;
 
-		  n = (str ? strlen (str) : 0);
+		  if (n >= 256) n = 255;
  		  if (n && KeySym_map [sym] == NULL)	/* not already set */
 		    {
-		       char *p = MALLOC ((n+1) * sizeof(char), "keysym");
-		       strcpy (p, str);
+		       char * p = MALLOC ((n+1) * sizeof(char), "keysym");
+		       p [0] = n;
+		       memcpy (p+1, str, n);
 		       KeySym_map [sym] = p;
 		    }
 	       }
@@ -637,7 +598,7 @@ get_xdefaults (FILE * stream, const char * name)
 	     const char * const kw = optList[entry].kw;
 	     if (kw == NULL) continue;
 	     n = strlen (kw);
-	     if ((str [n] == ':') && !strncmp (str, kw, n))
+	     if (str [n] == ':' && !strncmp (str, kw, n))
 	       {
 		  /* skip `keyword:' */
 		  str = trim_string (str + n + 1);
@@ -662,17 +623,19 @@ get_xdefaults (FILE * stream, const char * name)
      }
    rewind (stream);
 }
-#endif	/* FAKE_RESOURCES */
+/*}}}*/
+#endif	/* ! USE_XGETDEFAULT */
 #endif	/* NO_RESOURCES */
 
+/*{{{ read the resources files */
 /*
- * read the resources files
  * using XGetDefault() or the hand-rolled replacement
  */
 void
 extract_resources (Display * display, const char * name)
 {
-#if defined (REAL_RESOURCES)
+#ifndef NO_RESOURCES
+#ifdef USE_XGETDEFAULT
    /*
     * get resources using the X library function
     */
@@ -698,8 +661,7 @@ extract_resources (Display * display, const char * name)
 	       }
 	  }
      }
-
-#elif defined (FAKE_RESOURCES)
+#else	/* USE_XGETDEFAULT */
    /* get resources the hard way, but save lots of memory */
    const char * fname[] = { ".Xdefaults", ".Xresources" };
    FILE * fd = NULL;
@@ -728,9 +690,10 @@ extract_resources (Display * display, const char * name)
     * @ class resources (~/.Xdefaults)
     * @ private resources (~/.Xdefaults)
     *
-    * However, for FAKE_RESOURCES, the matching algorithm checks if a
-    * resource string value has already been allocated and won't overwrite
-    * it with (in this case) a less specific resource value.
+    * However, for the hand-rolled resources, the matching algorithm
+    * checks if a resource string value has already been allocated
+    * and won't overwrite it with (in this case) a less specific
+    * resource value.
     *
     * This avoids multiple allocation.  Also, when we've called this
     * routine command-line string options have already been applied so we
@@ -760,7 +723,8 @@ extract_resources (Display * display, const char * name)
    get_xdefaults (fd, "");		/* partial match */
    if (fd != NULL)
      fclose (fd);
-#endif	/* FAKE_RESOURCES */
+#endif	/* USE_XGETDEFAULT */
+#endif	/* NO_RESOURCES */
 
    /*
     * even without resources, at least do this setup for command-line
@@ -784,15 +748,11 @@ extract_resources (Display * display, const char * name)
 #define to_keysym(pks,str) do { KeySym sym;\
 if (str && ((sym = XStringToKeysym(str)) != 0)) *pks = sym; } while (0)
 
-#ifdef PRINTPIPE
-   to_keysym ( &ks_printscreen,	rs_printscreen_key );
+#if defined (HOTKEY_CTRL) || defined (HOTKEY_META)
+   to_keysym (&ks_bigfont,	rs_bigfont_key);
+   to_keysym (&ks_smallfont,	rs_smallfont_key);
 #endif
-#ifdef PASTE_KEY
-   to_keysym ( &ks_paste,	rs_paste_key );
-#endif
-
-   to_keysym ( &ks_bigfont,	rs_bigfont_key );
-   to_keysym ( &ks_smallfont,	rs_smallfont_key );
 #undef to_keysym
 }
+/*}}}*/
 /*----------------------- end-of-file (C source) -----------------------*/
